package restx.admin;

import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.ObjectWriter;
import com.google.common.base.Optional;
import static com.google.common.base.Preconditions.checkNotNull;

import restx.*;
import restx.factory.*;
import restx.description.*;
import restx.converters.MainStringConverter;
import static restx.common.MorePreconditions.checkPresent;

import javax.validation.Validator;
import static restx.validation.Validations.checkValid;

import java.io.IOException;
import java.io.PrintWriter;

@Component
public class AdminPagesResourceRouter extends RestxRouter {

    public AdminPagesResourceRouter(final AdminPagesResource resource, final ObjectMapper mapper, final MainStringConverter converter, final Validator validator) {
        super(
                "AdminPagesResourceRouter", new RestxRoute[] {
        new StdEntityRoute("default#AdminPagesResource#findPages", mapper, new StdRouteMatcher("GET", "/@/pages")) {
            @Override
            protected Optional<?> doRoute(RestxRequest request, RestxRouteMatch match) throws IOException {
                return Optional.of(resource.findPages(
                        /* [CONTEXT] baseUri */ request.getBaseUri()
                ));
            }

            protected ObjectWriter getObjectWriter(ObjectMapper mapper) { return super.getObjectWriter(mapper).withType(new TypeReference<java.lang.Iterable<restx.admin.AdminPage>>() { }); }

            @Override
            protected void describeOperation(OperationDescription operation) {
                

                operation.responseClass = "LIST[AdminPage]";
            }
        },
        });
    }

}
